# podaacpy
A test podaacpy package that contains commonly used functions for search and access the PODAAC products. 

## Installation

You can install the package using pip:

   pip install podaacpy

